@echo off
@rem This script will install LANSA Hot Fix files
@rem it will create backup file(s) and will back itself out if the install is unsuccessful
@rem it assumes it is being called from a subdirectory under the LANSA root directory
@setlocal

@echo.
if not "%1" == "" goto :usage

set EPClvl=759
set minEPClvl=759

cd files
if errorlevel 1 goto :wrongDir

set LR=..\..
if not exist %LR%\lansa                   goto :invalidRoot
if not exist %LR%\lansa\XSLEditor         goto :invalidRoot
if not exist %LR%\x_win95\x_lansa         goto :invalidRoot
if not exist %LR%\x_win95\x_lansa\execute goto :invalidRoot
if not exist %LR%\x_win95\x_lansa\source  goto :invalidRoot

find "3489" %LR%\build.dat > NUL
if errorlevel 1 goto :wrongVersion

find "x%EPClvl%" %LR%\EPCCheck.dat > NUL
if not errorlevel 1 goto :wrongEPClevel

find "E%minEPClvl%" %LR%\EPCCheck.dat > NUL
if errorlevel 1 goto :wrongEPClevel

@rem create/clean backup directories
set BUDIR=backup
for %%i in ( x_win95\x_lansa\execute x_win95\x_lansa\source lansa lansa\XSLEditor) do (
  @echo create backup dir for %%i\%BUDIR%
  if not exist %LR%\%%i\%BUDIR% mkdir %LR%\%%i\%BUDIR%
  @rem clean out directory
  del /q %LR%\%%i\%BUDIR%\*
)

@rem dir /b /l files

for %%i in (le*)   do call :copyFile %%i %LR%\x_win95\x_lansa\execute
for %%i in (lx*)   do call :copyFile %%i %LR%\x_win95\x_lansa\execute
for %%i in (x_*)   do call :copyFile %%i %LR%\x_win95\x_lansa\execute
for %%i in (u_*)   do call :copyFile %%i %LR%\x_win95\x_lansa\execute
for %%i in (*.s)   do call :copyFile %%i %LR%\x_win95\x_lansa\source
for %%i in (li*)   do call :copyFile %%i %LR%\lansa
for %%i in (XSLEditorFrame*)   do call :copyFile %%i %LR%\lansa
for %%i in (*.bnd) do call :copyFile %%i %LR%\lansa
for %%i in (x_base.dll x_dom.dll x_prim.dll x_rom.dll) do (
  if exist %%i        call :copyFile %%i %LR%\lansa
)
if exist XSLEditor (
  cd XSLEditor
  for %%i in (*)   do call :copyFile %%i ..\%LR%\lansa\XSLEditor
  cd ..
)


@rem delete bnb files if any bnd files exist
if exist *.bnd echo del /q %LR%\lansa\*.bnb

@rem OK files now updated, lets update epc.dat to record the fact
@echo ---LANSA Hot Fix (%DATE%) >> %LR%\epc.dat
type ..\hotfix.dat             >> %LR%\epc.dat



goto :theEnd

:copyFile
  @echo copy %1 %2
  @rem first make backup after ensuring we have write access
  attrib -R %2\%1
  @echo   Backup...
  copy %2\%1 %2\%BUDIR%
  @echo   Update...
  copy %1 %2
  if ERRORLEVEL 1 goto :copyFailed
  goto :EOF

:copyFailed
  @echo copy failed - restore backup files
  for %%i in ( x_win95\x_lansa\execute lansa ) do copy %LR%\%%i\%BUDIR%\* %LR%\%%i
  echo restore complete.
  echo.
  echo This window will now close when you hit any key. You may [Ctrl-C] to exit script
  pause
  exit 1

:wrongDir
@echo ERROR: %0 has not been run from the Hot Fix directory
goto :exitError

:invalidRoot
@echo ERROR: parent directory is NOT a valid LANSA root directory
goto :exitError

:wrongVersion
@echo ERROR: The LANSA root dirctory is not the correct version (11.0)
goto :exitError

:wrongEPClevel
@echo ERROR: The LANSA root dirctory is not the correct EPC level (%EPClvl%)
goto :exitError

:usage
@echo Usage: %0 
@echo.
@echo This command does not take any arguements

:exitError
@echo.
@echo This command assumes it is being run from a subdirectory under a valid LANSA
@echo root directory
@echo   For example:  "C:\Program Files\lansa\EPC761HF-051201"
@echo.
@echo This window will now close when you hit any key.
@echo You may [Ctrl-C] to exit script
@pause
exit /b 1

:theEnd
@echo.
@echo This window will now close when you hit any key.
@echo You may [Ctrl-C] to exit script
@pause
